@@ -1,4 +1,4 @@
-from .utils import Utils
+from .utils import SettingsReader
 import logging
 l = logging.getLogger("ppss.pyramidutils")
 import os,shutil,uuid,re,string,unicodedata
@@ -9,7 +9,7 @@ if not PY2:
 
 _valid_filename_chars = "-_.() %s%s" % (string.ascii_letters, string.digits)
 
-class FileManager(Utils):
+class FileManager(SettingsReader):
     savepath = "/tmp/finale"
     tmppath = "/tmp"
     myconf = ['savepath','tmppath']
