@@ -1,5 +1,6 @@
 from contextlib import contextmanager
 
+import time
 import logging
 l = logging.getLogger(__name__)
 
@@ -12,8 +13,13 @@ def engineFromSettings(config):
   return engine
 
 def factoryFormSettings(config):
-  engine = engineFromSettings(config)
-  session_factory = sessionmaker(bind=engine)
+  session_factory = None
+  try:
+    engine = engineFromSettings(config)
+    session_factory = sessionmaker(bind=engine)
+  except Exception as e:
+    l.exception("can't create session factory")
+    time.sleep(10)
   return session_factory
 
 
@@ -21,10 +27,10 @@ def factoryFormSettings(config):
 @contextmanager
 def session_scope(sessionFactory):
     session = sessionFactory()
-    l.info ("new session created")
+    l.debug ("new session created")
     try:
         yield session
-        l.info ("committing")
+        l.debug ("committing")
         session.commit()
     except Exception as e:
         session.rollback()
@@ -32,4 +38,4 @@ def session_scope(sessionFactory):
         raise e
     finally:
         session.close()
-        l.info ("session closed")
\ No newline at end of file
+        l.debug ("session closed")
\ No newline at end of file
